@@ -1,6 +1,6 @@
 package Net::DNS::RR::A;
 
-# $Id: A.pm,v 1.2 1997/02/02 08:31:25 mfuhr Exp $
+# $Id: A.pm,v 1.3 1997/06/13 03:33:54 mfuhr Exp $
 
 use strict;
 use vars qw(@ISA);
@@ -13,15 +13,32 @@ use Net::DNS;
 sub new {
 	my ($class, $self, $data, $offset) = @_;
 
-	my $addr = inet_ntoa(substr($$data, $offset, 4));
-	$self->{"address"} = $addr;
+	if ($self->{"rdlength"} > 0) {
+		my $addr = inet_ntoa(substr($$data, $offset, 4));
+		$self->{"address"} = $addr;
+	}
+
 	return bless $self, $class;
 }
 
 sub rdatastr {
 	my $self = shift;
-	return $self->{"address"};
+
+	return exists $self->{"address"} && $self->{"address"}
+	       ? $self->{"address"}
+	       : "; no data";
 }
+
+sub rr_rdata {
+	my $self = shift;
+
+	my $rdata = exists $self->{"address"}
+		  ? inet_aton($self->{"address"})
+		  : "";
+
+	return $rdata;
+}
+
 1;
 __END__
 
